Changelog
=========


1.0.0a2 (2022-07-20)
--------------------

- avoid to have Products.DateRecurringIndex.index.DateRecurringIndex between the valueindexes


1.0.0a1 (2022-07-18)
--------------------

- Initial release
